# nx-migrate Package

## installation
```
pip install nx-migrate
```

## Notice
the `nx` command must be available in your `system's PATH` for this script to work.

## Usage
- Example on Windows
```
nx-migrate -u "C:\my-monorepo"
```

- Example on Linux/macOS
```
nx-migrate -u "/Users/me/my-monorepo"
```

